// TidyOptions.cpp : Implementation of CTidyOptions
#include "stdafx.h"
#include "TidyCOM.h"
#include "TidyOptions.h"

//-------------------------------------------------------------------
// CTidyOptions

HRESULT CTidyOptions::FinalConstruct()
{
	return S_OK;
}

void CTidyOptions::FinalRelease()
{
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// ISupportsErrorInfo
STDMETHODIMP CTidyOptions::InterfaceSupportsErrorInfo(REFIID riid)
{
	static const IID* arr[] = 
	{
		&IID_ITidyOptions
	};
	for (int i=0; i < sizeof(arr) / sizeof(arr[0]); i++)
	{
		if (InlineIsEqualGUID(*arr[i],riid))
			return S_OK;
	}
	return S_FALSE;
}

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
// ITidyOptions

STDMETHODIMP CTidyOptions::SetPtr(long val)
{
	m_pTidyProxy = reinterpret_cast<CTidyProxy*>(val);

	return S_OK;
}

STDMETHODIMP CTidyOptions::Load(BSTR configFile)
{
	USES_CONVERSION;
	try {
		m_pTidyProxy->LoadConfig(OLE2T(configFile));
	}
	catch (...) {
		return Error("HTML Tidy exception");
	}

	return S_OK;
}

STDMETHODIMP CTidyOptions::Reset()
{
	m_pTidyProxy->ResetConfig();

	return S_OK;
}

//-   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  
// Markup
STDMETHODIMP CTidyOptions::get_Doctype(BSTR *pVal)
{
	USES_CONVERSION;
	*pVal = T2BSTR(m_pTidyProxy->GetDocType().c_str());

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Doctype(BSTR newVal)
{
	USES_CONVERSION;
	m_pTidyProxy->SetDocType(OLE2T(newVal));

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_TidyMark(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetTidyMark() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_TidyMark(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetTidyMark(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_HideEndtags(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetHideEndTags() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_HideEndtags(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetHideEndTags(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_EncloseText(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetEncloseBodyText() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_EncloseText(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetEncloseBodyText(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_EncloseBlockText(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetEncloseBlockText() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_EncloseBlockText(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetEncloseBlockText(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_NewEmptyTags(BSTR *pVal)
{
	USES_CONVERSION;
	*pVal = T2BSTR(m_pTidyProxy->GetNewTags(CTidyProxy::NewEmptyTags).c_str());

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_NewEmptyTags(BSTR newVal)
{
	USES_CONVERSION;
	m_pTidyProxy->SetNewTags(CTidyProxy::NewEmptyTags, OLE2T(newVal));

	return S_OK;
}
STDMETHODIMP CTidyOptions::get_NewInlineTags(BSTR *pVal)
{
	USES_CONVERSION;
	*pVal = T2BSTR(m_pTidyProxy->GetNewTags(CTidyProxy::NewInlineTags).c_str());

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_NewInlineTags(BSTR newVal)
{
	USES_CONVERSION;
	m_pTidyProxy->SetNewTags(CTidyProxy::NewInlineTags, OLE2T(newVal));

	return S_OK;
}
STDMETHODIMP CTidyOptions::get_NewBlocklevelTags(BSTR *pVal)
{
	USES_CONVERSION;
	*pVal = T2BSTR(m_pTidyProxy->GetNewTags(CTidyProxy::NewBlockTags).c_str());

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_NewBlocklevelTags(BSTR newVal)
{
	USES_CONVERSION;
	m_pTidyProxy->SetNewTags(CTidyProxy::NewBlockTags, OLE2T(newVal));

	return S_OK;
}
STDMETHODIMP CTidyOptions::get_NewPreTags(BSTR *pVal)
{
	USES_CONVERSION;
	*pVal = T2BSTR(m_pTidyProxy->GetNewTags(CTidyProxy::NewPreTags).c_str());

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_NewPreTags(BSTR newVal)
{
	USES_CONVERSION;
	m_pTidyProxy->SetNewTags(CTidyProxy::NewPreTags, OLE2T(newVal));

	return S_OK;
}

//-   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  
// Cleanup
STDMETHODIMP CTidyOptions::get_Clean(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetMakeClean() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Clean(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetMakeClean(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_DropFontTags(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetDropFontTags() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_DropFontTags(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetDropFontTags(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_LogicalEmphasis(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetLogicalEmphasis() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_LogicalEmphasis(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetLogicalEmphasis(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_DropEmptyParas(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetDropEmptyParas() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_DropEmptyParas(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetDropEmptyParas(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_Word2000(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetWord2000() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Word2000(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetWord2000(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_FixBadComments(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetFixComments() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_FixBadComments(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetFixComments(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_FixBackslash(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetFixBackslash() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_FixBackslash(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetFixBackslash(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_AltText(BSTR *pVal)
{
	USES_CONVERSION;
	*pVal = T2BSTR(m_pTidyProxy->GetAltText().c_str());

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_AltText(BSTR newVal)
{
	USES_CONVERSION;
	m_pTidyProxy->SetAltText(OLE2T(newVal));

	return S_OK;
}

//-   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  
// XML
STDMETHODIMP CTidyOptions::get_InputXml(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetXmlTags() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_InputXml(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetXmlTags(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_OutputXml(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetXmlOut() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_OutputXml(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetXmlOut(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_OutputXhtml(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetxHTML() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_OutputXhtml(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetxHTML(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_AddXmlDecl(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetXmlPi() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_AddXmlDecl(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetXmlPi(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_AssumeXmlProcins(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetXmlPIs() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_AssumeXmlProcins(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetXmlPIs(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_AddXmlSpace(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetXmlSpace() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_AddXmlSpace(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetXmlSpace(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

//-   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  
// Encoding
STDMETHODIMP CTidyOptions::get_CharEncoding(CharEncoding *pVal)
{
	switch (m_pTidyProxy->GetCharEncoding()) {
	case CTidyProxy::Enc_Raw: *pVal = raw; break;
	case CTidyProxy::Enc_ASCII: *pVal = ascii; break;
	case CTidyProxy::Enc_Latin1: *pVal = latin1; break;
	case CTidyProxy::Enc_UTF8: *pVal = utf8; break;
	case CTidyProxy::Enc_ISO2022: *pVal = iso2022; break;
	case CTidyProxy::Enc_MacRoman: *pVal = macroman; break;
	default: *pVal = ascii;
	}

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_CharEncoding(CharEncoding newVal)
{
	switch (newVal) {
	case raw: m_pTidyProxy->SetCharEncoding(CTidyProxy::Enc_Raw); break;
	case ascii: m_pTidyProxy->SetCharEncoding(CTidyProxy::Enc_ASCII); break;
	case latin1: m_pTidyProxy->SetCharEncoding(CTidyProxy::Enc_Latin1); break;
	case utf8: m_pTidyProxy->SetCharEncoding(CTidyProxy::Enc_UTF8); break;
	case iso2022: m_pTidyProxy->SetCharEncoding(CTidyProxy::Enc_ISO2022); break;
	case macroman: m_pTidyProxy->SetCharEncoding(CTidyProxy::Enc_MacRoman); break;
	default: m_pTidyProxy->SetCharEncoding(CTidyProxy::Enc_ASCII);
	}

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_NumericEntities(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetNumEntities() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_NumericEntities(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetNumEntities(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_QuoteMarks(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetQuoteMarks() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_QuoteMarks(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetQuoteMarks(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_QuoteNbsp(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetQuoteNbsp() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_QuoteNbsp(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetQuoteNbsp(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_QuoteAmpersand(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetQuoteAmpersand() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_QuoteAmpersand(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetQuoteAmpersand(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

//-   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  
// Layout
STDMETHODIMP CTidyOptions::get_Indent(IndentScheme *pVal)
{
	switch (m_pTidyProxy->GetIndent()) {
	case CTidyProxy::Log3_False: *pVal = NoIndent; break;
	case CTidyProxy::Log3_True: *pVal = IndentBlocks; break;
	case CTidyProxy::Log3_Maybe: *pVal = AutoIndent; break;
	default: *pVal = NoIndent;
	}

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Indent(IndentScheme newVal)
{
	switch (newVal) {
	case NoIndent: m_pTidyProxy->SetIndent(CTidyProxy::Log3_False); break;
	case IndentBlocks: m_pTidyProxy->SetIndent(CTidyProxy::Log3_True); break;
	case AutoIndent: m_pTidyProxy->SetIndent(CTidyProxy::Log3_Maybe); break;
	default: m_pTidyProxy->SetIndent(CTidyProxy::Log3_False);
	}

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_IndentSpaces(long *pVal)
{
	*pVal = m_pTidyProxy->GetIndentSpaces();

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_IndentSpaces(long newVal)
{
	m_pTidyProxy->SetIndentSpaces(newVal);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_Wrap(long *pVal)
{
	*pVal = m_pTidyProxy->GetWrapMargin();

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Wrap(long newVal)
{
	m_pTidyProxy->SetWrapMargin(newVal);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_TabSize(long *pVal)
{
	*pVal = m_pTidyProxy->GetTabSize();

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_TabSize(long newVal)
{
	m_pTidyProxy->SetTabSize(newVal);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_IndentAttributes(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetIndentAttributes() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_IndentAttributes(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetIndentAttributes(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_WrapAttributes(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetWrapAttVals() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_WrapAttributes(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetWrapAttVals(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_WrapScriptLiterals(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetWrapScriptlets() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_WrapScriptLiterals(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetWrapScriptlets(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_WrapAsp(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetWrapAsp() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_WrapAsp(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetWrapAsp(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_WrapJste(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetWrapJste() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_WrapJste(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetWrapJste(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_WrapPhp(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetWrapPhp() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_WrapPhp(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetWrapPhp(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_BreakBeforeBr(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetBreakBeforeBR() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_BreakBeforeBr(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetBreakBeforeBR(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_UppercaseTags(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetUpperCaseTags() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_UppercaseTags(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetUpperCaseTags(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_UppercaseAttributes(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetUpperCaseAttrs() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_UppercaseAttributes(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetUpperCaseAttrs(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_LiteralAttributes(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetLiteralAttribs() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_LiteralAttributes(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetLiteralAttribs(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

//-   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -   -  
// Operation
STDMETHODIMP CTidyOptions::get_Markup(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetOnlyErrors() ? VARIANT_FALSE : VARIANT_TRUE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Markup(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetOnlyErrors(newVal == VARIANT_TRUE ? false : true);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_Quiet(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetQuiet() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Quiet(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetQuiet(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_ShowWarnings(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetShowWarnings() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_ShowWarnings(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetShowWarnings(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_Split(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetBurstSlides() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_Split(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetBurstSlides(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_KeepTime(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetKeepFileTimes() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_KeepTime(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetKeepFileTimes(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_ErrorFile(BSTR *pVal)
{
	USES_CONVERSION;
	*pVal = T2BSTR(m_pTidyProxy->GetErrorFile().c_str());

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_ErrorFile(BSTR newVal)
{
	USES_CONVERSION;
	m_pTidyProxy->SetErrorFile(OLE2T(newVal));

	return S_OK;
}

STDMETHODIMP CTidyOptions::get_GnuEmacs(VARIANT_BOOL *pVal)
{
	*pVal = m_pTidyProxy->GetEmacs() ? VARIANT_TRUE : VARIANT_FALSE;

	return S_OK;
}
STDMETHODIMP CTidyOptions::put_GnuEmacs(VARIANT_BOOL newVal)
{
	m_pTidyProxy->SetEmacs(newVal == VARIANT_TRUE ? true : false);

	return S_OK;
}
